==> wisski-8.x-1.1.tar.gz: wisski/wisski_iip_image/src/Plugin/ImageToolkit/Operation/imagemagick/Pyramid.php <==
<?php

/**
 * @file
 * Contains \Drupal\wisski_iip_image\Plugin\ImageToolkit\Operation\imagemagick\Pyramid.
 */

namespace Drupal\wisski_iip_image\Plugin\ImageToolkit\Operation\imagemagick;

use Drupal\imagemagick\Plugin\ImageToolkit\Operation\imagemagick\ImagemagickImageToolkitOperationBase;

/**
 * Defines imagemagick Scale operation.
 *
 * @ImageToolkitOperation(
 *   id = "WisskiIIPImage_pyramid",
 *   toolkit = "imagemagick",
 *   operation = "pyramid",
 *   label = @Translation("Pyramid"),
 *   description = @Translation("Generates a pyramidal derivative.")
 * )
 */
class Pyramid extends ImagemagickImageToolkitOperationBase {

  /**
   * {@inheritdoc}
   */
  protected function arguments() {
    return array(
/*      'width' => array(
        'description' => 'The target width, in pixels. This value is omitted then the scaling will based only on the height value',
        'required' => FALSE,
        'default' => NULL,
      ),
      'height' => array(
        'description' => 'The target height, in pixels. This value is omitted then the scaling will based only on the width value',
        'required' => FALSE,
        'default' => NULL,
      ),
      'upscale' => array(
        'description' => 'Boolean indicating that files smaller than the dimensions will be scaled up. This generally results in a low quality image',
        'required' => FALSE,
        'default' => FALSE,
      ),*/
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function validateArguments(array $arguments) {
/*
    // Assure at least one dimension.
    if (empty($arguments['width']) && empty($arguments['height'])) {
      throw new \InvalidArgumentException("At least one dimension ('width' or 'height') must be provided to the image 'scale' operation");
    }

    // Calculate one of the dimensions from the other target dimension,
    // ensuring the same aspect ratio as the source dimensions. If one of the
    // target dimensions is missing, that is the one that is calculated. If both
    // are specified then the dimension calculated is the one that would not be
    // calculated to be bigger than its target.
    $aspect = $this->getToolkit()->getHeight() / $this->getToolkit()->getWidth();
    if (($arguments['width'] && !$arguments['height']) || ($arguments['width'] && $arguments['height'] && $aspect < $arguments['height'] / $arguments['width'])) {
      $arguments['height'] = (int) round($arguments['width'] * $aspect);
    }
    else {
      $arguments['width'] = (int) round($arguments['height'] / $aspect);
    }

    // Assure integers for all arguments.
    $arguments['width'] = (int) round($arguments['width']);
    $arguments['height'] = (int) round($arguments['height']);

    // Fail when width or height are 0 or negative.
    if ($arguments['width'] <= 0) {
      throw new \InvalidArgumentException("Invalid width ('{$arguments['width']}') specified for the image 'scale' operation");
    }
    if ($arguments['height'] <= 0) {
      throw new \InvalidArgumentException("Invalid height ('{$arguments['height']}') specified for the image 'scale' operation");
    }

    return $arguments;
*/
#  return true;
    return $arguments;
  }

  /**
   * {@inheritdoc}
   */
  protected function execute(array $arguments = array()) {
#    // Don't scale if we don't change the dimensions at all.
#    if ($arguments['width'] !== $this->getToolkit()->getWidth() || $arguments['height'] !== $this->getToolkit()->getHeight()) {
#      // Don't upscale if the option isn't enabled.
#      if ($arguments['upscale'] || ($arguments['width'] <= $this->getToolkit()->getWidth() && $arguments['height'] <= $this->getToolkit()->getHeight())) {
#        return parent::execute($arguments);
#      }
#    }
#    drupal_set_message("Hallo welt!" . serialize($this->getToolkit()));
#    $command = 'convert ' . $this->getToolkit()->escapeShellArg($this->getToolkit()->getSourceLocalPath()) . " -define tiff:tile-geometry=256x256 -compress jpeg 'ptif:-'";
    $this->getToolkit()->resetArguments();
    $this->getToolkit()->addArgument('-define tiff:tile-geometry=256x256 -compress jpeg');
    $this->getToolkit()->addArgument('-quality 100');
    $this->getToolkit()->setDestinationFormat('ptif');

#    dpm($this->getToolkit()->addArgument($command));
#    dpm($this->getToolkit()->imagemagickExec($command));
    return TRUE;
  }

}

==> wisski-8.x-2.2.tar.gz: wisski/wisski_iip_image/src/Plugin/ImageToolkit/Operation/imagemagick/Pyramid.php <==
<?php

/**
 * @file
 * Contains \Drupal\wisski_iip_image\Plugin\ImageToolkit\Operation\imagemagick\Pyramid.
 */

namespace Drupal\wisski_iip_image\Plugin\ImageToolkit\Operation\imagemagick;

use Drupal\imagemagick\Plugin\ImageToolkit\Operation\imagemagick\ImagemagickImageToolkitOperationBase;

/**
 * Defines imagemagick Scale operation.
 *
 * @ImageToolkitOperation(
 *   id = "WisskiIIPImage_pyramid",
 *   toolkit = "imagemagick",
 *   operation = "pyramid",
 *   label = @Translation("Pyramid"),
 *   description = @Translation("Generates a pyramidal derivative.")
 * )
 */
class Pyramid extends ImagemagickImageToolkitOperationBase {

  /**
   * {@inheritdoc}
   */
  protected function arguments() {
    return array(
/*      'width' => array(
        'description' => 'The target width, in pixels. This value is omitted then the scaling will based only on the height value',
        'required' => FALSE,
        'default' => NULL,
      ),
      'height' => array(
        'description' => 'The target height, in pixels. This value is omitted then the scaling will based only on the width value',
        'required' => FALSE,
        'default' => NULL,
      ),
      'upscale' => array(
        'description' => 'Boolean indicating that files smaller than the dimensions will be scaled up. This generally results in a low quality image',
        'required' => FALSE,
        'default' => FALSE,
      ),*/
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function validateArguments(array $arguments) {
/*
    // Assure at least one dimension.
    if (empty($arguments['width']) && empty($arguments['height'])) {
      throw new \InvalidArgumentException("At least one dimension ('width' or 'height') must be provided to the image 'scale' operation");
    }

    // Calculate one of the dimensions from the other target dimension,
    // ensuring the same aspect ratio as the source dimensions. If one of the
    // target dimensions is missing, that is the one that is calculated. If both
    // are specified then the dimension calculated is the one that would not be
    // calculated to be bigger than its target.
    $aspect = $this->getToolkit()->getHeight() / $this->getToolkit()->getWidth();
    if (($arguments['width'] && !$arguments['height']) || ($arguments['width'] && $arguments['height'] && $aspect < $arguments['height'] / $arguments['width'])) {
      $arguments['height'] = (int) round($arguments['width'] * $aspect);
    }
    else {
      $arguments['width'] = (int) round($arguments['height'] / $aspect);
    }

    // Assure integers for all arguments.
    $arguments['width'] = (int) round($arguments['width']);
    $arguments['height'] = (int) round($arguments['height']);

    // Fail when width or height are 0 or negative.
    if ($arguments['width'] <= 0) {
      throw new \InvalidArgumentException("Invalid width ('{$arguments['width']}') specified for the image 'scale' operation");
    }
    if ($arguments['height'] <= 0) {
      throw new \InvalidArgumentException("Invalid height ('{$arguments['height']}') specified for the image 'scale' operation");
    }

    return $arguments;
*/
#  return true;
    return $arguments;
  }

  /**
   * {@inheritdoc}
   */
  protected function execute(array $arguments = array()) {
#    // Don't scale if we don't change the dimensions at all.
#    if ($arguments['width'] !== $this->getToolkit()->getWidth() || $arguments['height'] !== $this->getToolkit()->getHeight()) {
#      // Don't upscale if the option isn't enabled.
#      if ($arguments['upscale'] || ($arguments['width'] <= $this->getToolkit()->getWidth() && $arguments['height'] <= $this->getToolkit()->getHeight())) {
#        return parent::execute($arguments);
#      }
#    }
#    drupal_set_message("Hallo welt!" . serialize($this->getToolkit()));
#    $command = 'convert ' . $this->getToolkit()->escapeShellArg($this->getToolkit()->getSourceLocalPath()) . " -define tiff:tile-geometry=256x256 -compress jpeg 'ptif:-'";
#    $this->getToolkit()->resetArguments();
    $this->getToolkit()->arguments()->reset();
    // jpeg compression may cause problems in grayscale images!
#    $this->getToolkit()->arguments()->add('-define tiff:tile-geometry=256x256 -compress jpeg');
    $this->getToolkit()->arguments()->add('-define tiff:tile-geometry=256x256');
    $this->getToolkit()->arguments()->add('-quality 100');
    $this->getToolkit()->arguments()->setDestinationFormat('ptif');

#    dpm($this->getToolkit()->addArgument($command));
#    dpm($this->getToolkit()->imagemagickExec($command));
    return TRUE;
  }

}
